#include <stdio.h> //printf
#include <string.h>    //strlen
#include <sys/socket.h>    //socket
#include <arpa/inet.h> //inet_addr
#include <stdlib.h>
#include "common.h"

void usage();

int main(int argc , char *argv[])
{
    // check param validity
    if (argc != 3)
    {
        debug("Invalid number of arguments.\n");
        usage();
        return 1;
    }

    char remote_ip_address[IP_ADDRESS_SIZE];

    // Parse application arguments.
    memcpy(remote_ip_address, argv[1], strlen(argv[1]));
    int remote_port = atoi(argv[2]);

    debug_n("poll_simulator connecting to %s:%d.", remote_ip_address, remote_port);

    int sock = persistent_connect(remote_ip_address, remote_port);
    if (sock < 0)
    {
        debug_n("Error during connect. Exiting.");
        return 1;
    }

    start_tcp_stats_collecting(sock);

    int message_counter = 0;
    int message_buffer_size = sizeof(char) * 1024 * 1024;
    char *message_buffer = malloc(message_buffer_size);
    for(;;)
    {
        // receive mesage size
        int message_size = ReceiveMessage(sock, message_buffer, message_buffer_size);

        if (message_size < 0)
        {
            debug_n("Received too big message: %d.", message_size);
            return 2;
        }

        message_counter++;
        if (message_counter % 10000 == 0)
        {
            debug_n("Number of messages received is %d.", message_counter);
        }
    }

    close(sock);
    free(message_buffer);

    return 0;
}

void usage()
{
	debug_n("Application connects to stream_traffic_generator application and receives data.");
	debug_n("Usage:");
	debug_n("stream_traffic_sink remote_ip_address remote_port");
}

